@@ -104,6 +104,12 @@ class DateRange:
 
         keywords_week = ["本周", "上周"] 
         reg = re.findall(r'(\d+)', datestr)
+        reg2 = re.findall(r'上周\D+', datestr)
+        reg3 = re.findall(r'上周$', datestr)
+
+        if reg2 or reg3:
+            return __week.get("上周")
+
         if len(reg) == 1: day = int(reg[0])
         else: day = 1
         for word in keywords_week:
